@@ -1,6 +1,6 @@
 package Map::Tube::Table;
 
-$Map::Tube::Table::VERSION = '2.31';
+$Map::Tube::Table::VERSION = '2.32';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Map::Tube::Table - Class to represent the table in the map.
 
 =head1 VERSION
 
-Version 2.31
+Version 2.32
 
 =cut
 
@@ -17,7 +17,7 @@ use 5.006;
 use Moo;
 use namespace::clean;
 
-has id     => (is => 'ro');
+has id     => (is => 'ro', required => 1);
 has path   => (is => 'rw');
 has length => (is => 'rw');
 
